@@ -10,10 +10,12 @@ def qunat(flie_path,write_path,name_idx,qianzhui='',info_idx=''):
     name = []
 
     for i in range(df.shape[0]):
-        if pd.isnull(df.iloc[i,info_idx-1]) and ('@'+df.iloc[i,name_idx-1]) not in name:
-            name.append(qianzhui + df.iloc[i,name_idx-1])
+        
+        if pd.isnull(df.iloc[i,info_idx-1]) and (str(qianzhui)+str(df.iloc[i,name_idx-1]) ) not in name:
+            name.append(str(qianzhui) + str(df.iloc[i,name_idx-1]))
 
     name = pd.DataFrame(name)
     name = pd.DataFrame(name.iloc[:,0].unique())    #去重
 
-    name.to_csv(write_path,index=None,header=None)
\ No newline at end of file
+    name.to_csv(write_path,index=None,header=None)
+    print(name)
\ No newline at end of file
